# ⌨️ Keybind Vault

A TUI (Text-based User Interface) app built with [Textual](https://github.com/Textualize/textual) for managing your keyboard shortcuts. Organize, search, add, edit, and delete keybinds in a sleek terminal interface.

---

## Features

- **Dark Mode** toggle
- **Search** keybinds by keys, name, or description
- **Add**, **Edit**, **Delete** keybinds
- Organize keybinds into categories
- Uses a lightweight sqlite3 database for storage

---

## Preview

> *(Add a screenshot or GIF of your terminal UI here, if possible)*

---

## Getting Started

### 1. Clone the repo

```bash
git clone https://github.com/your-username/keybind-vault.git
cd keybind-vault
```

### 2. Set up a virtual environment

```bash
python -m venv .venv
source .venv/bin/activate    # On Windows: .venv\Scripts\activate
```

### 3. Install dependencies

```bash
pip install -r requirements.txt
```

### 4. Run the application

```bash
python -m keybind_vault
```

Or if installed via an entry point (e.g. via `setup.py`):

```bash
keybind-vault
```

---

## Project Structure

```text
keybind_vault/
│
├── db/                    # SQLite database logic
│   ├── __init__.py
│   └── sqlite_db.py
│
├── modals/                # Textual modal screens for Add, Edit, Delete, etc.
│   ├── styles/            # Textual CSS for the modal screens
│   ├── add_modal.py
│   ├── delete_modal.py
│   ├── edit_modal.py
│   ├── search_modal.py
│   ├── vault_types.py
│   └── __init__.py
│
├── styles/
│   └── styles.tcss        # Textual CSS for the main file
│
├── main.py                # Main Textual app logic
└── __init__.py
```

---

## Tech Stack

- [Textual](https://github.com/Textualize/textual) — modern TUI framework for Python
- Python 3.13+
- SQLite (via `sqlite3` module)
